@@ -9,6 +9,6 @@ fn test_trades() {
 
 #[test]
 fn test_l2_snapshot() {
-    let text = fetch_l2_snapshot("bitmex", MarketType::InverseSwap, "XBTUSD").unwrap();
+    let text = fetch_l2_snapshot("bitmex", MarketType::InverseSwap, "XBTUSD", Some(3)).unwrap();
     assert!(text.starts_with("[{"));
 }
